==> ui-react-1.0.84.tgz: package/esm/AutoCompleteGooglePlaces/AutoCompleteGooglePlaces.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["value", "valueDefault", "valueInputDefault", "onChangeInput", "size", "optionsGoogle", "className", "children"];
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
import React from 'react';
import { debounce, is } from '@onesy/utils';
import { classNames, style as styleMethod, useOnesyTheme } from '@onesy/style-react';
import AutoCompleteElement from '../AutoComplete';
import ListItemElement from '../ListItem';
import TypeElement from '../Type';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {}
}), {
  name: 'onesy-AutoCompleteGooglePlaces'
});
const AutoCompleteGooglePlaces = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useOnesyTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.onesyAutoCompleteGooglePlaces?.props?.default), props_), [props_]);
  const AutoComplete = React.useMemo(() => theme?.elements?.AutoComplete || AutoCompleteElement, [theme]);
  const ListItem = React.useMemo(() => theme?.elements?.ListItem || ListItemElement, [theme]);
  const Type = React.useMemo(() => theme?.elements?.Type || TypeElement, [theme]);
  const {
      value,
      valueDefault,
      valueInputDefault: valueInputDefault_,
      onChangeInput: onChangeInputProps,
      size = 'regular',
      optionsGoogle: optionsGoogle_,
      className,
      children
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const [places, setPlaces] = React.useState([]);
  const refs = {
    google: React.useRef(undefined)
  };
  const optionsGoogle = React.useMemo(() => {
    return optionsGoogle_ || {
      fields: ['name', 'address_component', 'location', 'geometry']
    };
  }, [optionsGoogle_]);
  const onGoogleResults = React.useCallback(results => {
    // update places
    setPlaces(results?.map(item => _objectSpread(_objectSpread({}, item), {}, {
      name: item.description
    })) || []);
  }, []);
  const init = React.useCallback(async () => {
    if (!window.google) return;
    const google = window.google;
    const {
      AutocompleteService
    } = await google.maps.importLibrary('places');
    refs.google.current = new AutocompleteService(undefined, options);
  }, []);
  React.useEffect(() => {
    // init
    init();
  }, []);
  const onChangeInput = React.useCallback(debounce(valueNew => {
    if (is('function', onChangeInputProps)) onChangeInputProps(valueNew);
    if (!refs.google.current) return;

    // Make a Google request
    refs.google.current.getQueryPredictions({
      input: valueNew
    }, onGoogleResults);
  }, 440), [optionsGoogle, onChangeInputProps]);
  const options = React.useMemo(() => {
    return places.map(item => _objectSpread(_objectSpread({}, item), {}, {
      value: item.name
    }));
  }, [places]);
  const valueInputDefault = React.useMemo(() => {
    return valueInputDefault_ !== undefined ? valueInputDefault_ : options.find(item => item.value === (value !== undefined ? value : valueDefault))?.name;
  }, []);
  return /*#__PURE__*/React.createElement(AutoComplete, _extends({
    ref: ref,
    valueInputDefault: valueInputDefault,
    valueDefault: valueDefault,
    value: value,
    options: options,
    onChangeInput: onChangeInput,
    size: size,
    renderOption: (item, index_, propsItem) => /*#__PURE__*/React.createElement(ListItem, _extends({
      key: index_,
      start: item.flag,
      startAlign: "center",
      primary: /*#__PURE__*/React.createElement(Type, {
        version: "b3"
      }, item.name),
      value: item.value,
      selected: item.value === (value?.value !== undefined ? value?.value : value),
      size: "small",
      button: true
    }, propsItem)),
    className: classNames([staticClassName('AutoCompleteGooglePlaces', theme) && ['onesy-AutoCompleteGooglePlaces-root', `onesy-AutoCompleteGooglePlaces-size-${size}`], className, classes.root])
  }, other));
});
AutoCompleteGooglePlaces.displayName = 'onesy-AutoCompleteGooglePlaces';
export default AutoCompleteGooglePlaces;

==> ui-react-1.1.846.tgz: package/esm/AutoCompleteGooglePlaces/AutoCompleteGooglePlaces.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["value", "valueDefault", "valueInputDefault", "onChangeInput", "size", "optionsGoogle", "className", "children"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import { debounce, is } from '@amaui/utils';
import { classNames, style as styleMethod, useAmauiTheme } from '@amaui/style-react';
import AutoCompleteElement from '../AutoComplete';
import ListItemElement from '../ListItem';
import TypeElement from '../Type';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {}
}), {
  name: 'amaui-AutoCompleteGooglePlaces'
});
const AutoCompleteGooglePlaces = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useAmauiTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.amauiAutoCompleteGooglePlaces?.props?.default), props_), [props_]);
  const AutoComplete = React.useMemo(() => theme?.elements?.AutoComplete || AutoCompleteElement, [theme]);
  const ListItem = React.useMemo(() => theme?.elements?.ListItem || ListItemElement, [theme]);
  const Type = React.useMemo(() => theme?.elements?.Type || TypeElement, [theme]);
  const {
      value,
      valueDefault,
      valueInputDefault: valueInputDefault_,
      onChangeInput: onChangeInputProps,
      size = 'regular',
      optionsGoogle: optionsGoogle_,
      className,
      children
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const [places, setPlaces] = React.useState([]);
  const refs = {
    google: React.useRef(undefined)
  };
  const optionsGoogle = React.useMemo(() => {
    return optionsGoogle_ || {
      fields: ['name', 'address_component', 'location', 'geometry']
    };
  }, [optionsGoogle_]);
  const onGoogleResults = React.useCallback(results => {
    // update places
    setPlaces(results?.map(item => _objectSpread(_objectSpread({}, item), {}, {
      name: item.description
    })) || []);
  }, []);
  const init = React.useCallback(async () => {
    if (!window.google) return;
    const google = window.google;
    const {
      AutocompleteService
    } = await google.maps.importLibrary('places');
    refs.google.current = new AutocompleteService(undefined, options);
  }, []);
  React.useEffect(() => {
    // init
    init();
  }, []);
  const onChangeInput = React.useCallback(debounce(valueNew => {
    if (is('function', onChangeInputProps)) onChangeInputProps(valueNew);
    if (!refs.google.current) return;

    // Make a Google request
    refs.google.current.getQueryPredictions({
      input: valueNew
    }, onGoogleResults);
  }, 440), [optionsGoogle, onChangeInputProps]);
  const options = React.useMemo(() => {
    return places.map(item => _objectSpread(_objectSpread({}, item), {}, {
      value: item.name
    }));
  }, [places]);
  const valueInputDefault = React.useMemo(() => {
    return valueInputDefault_ !== undefined ? valueInputDefault_ : options.find(item => item.value === (value !== undefined ? value : valueDefault))?.name;
  }, []);
  return /*#__PURE__*/React.createElement(AutoComplete, _extends({
    ref: ref,
    valueInputDefault: valueInputDefault,
    valueDefault: valueDefault,
    value: value,
    options: options,
    onChangeInput: onChangeInput,
    size: size,
    renderOption: (item, index_, propsItem) => /*#__PURE__*/React.createElement(ListItem, _extends({
      key: index_,
      start: item.flag,
      startAlign: "center",
      primary: /*#__PURE__*/React.createElement(Type, {
        version: "b3"
      }, item.name),
      value: item.value,
      selected: item.value === (value?.value !== undefined ? value?.value : value),
      size: "small",
      button: true
    }, propsItem)),
    className: classNames([staticClassName('AutoCompleteGooglePlaces', theme) && ['amaui-AutoCompleteGooglePlaces-root', `amaui-AutoCompleteGooglePlaces-size-${size}`], className, classes.root])
  }, other));
});
AutoCompleteGooglePlaces.displayName = 'amaui-AutoCompleteGooglePlaces';
export default AutoCompleteGooglePlaces;
